"""This program illustrates the use of dictionaries to count the
number of movies for each actor. 

Read movie data into a dictionary called movies:
   key: name of an actor
   value: the number of movies for that actor

This program finds the actors with the top 10 number of movies

Complexity:

person in actors, O(1): 1 comparison (in the average)
update movies[person], O(1): 1 comparison (in the average)
actors.add(), O(1): 1 comparison (in the average)

these two are repeated for all lines (n) in the imdb_data, i.e. n
times, so total complexity is O(n), i.e. linear. (in the average)

"""

if __name__ == '__main__':
    movies = {}
    actors = set()
    for line in open("imdb_data.txt"):
        m = line.strip().split("|")
        person = m[0].strip()
        movie = m[1].strip()
        
        ##Note: person in movies.keys() is O(n) and hence too costly
        ##So, we keep the list of all actors in a set and use that instead
        ##to speed things up
        if person in actors:  
            movies[person] += 1
        else:
            movies[person] = 1
            actors.add( person )

    ##Find actors with the highest number of movies
    movie_counts = []
    for key in movies.keys():
        movie_counts.append( [movies[key], key] )
    movie_counts.sort(reverse=True)
    
    for i in range(10):
        print "%i. %s (%d movies)" %(i+1, movie_counts[i][1], movie_counts[i][0])
        

