"""

This program illustrates the use of dictionaries to count the
number of movies for each actor. We first store the values in 
a set, then use the set to count.

While this is a more expensive solution than "hanks_dictionary.txt",
it can be more accurate. Why? Compare solutions with this file and
think why the values are different.

Read movie data into a dictionary called movies:
   key: name of an actor
   value: set of all the movies for that actor

This program finds the actors with the top 10 number of movies


"""

if __name__ == '__main__':
    movies = {}
    actors = set()
    for line in open("imdb_data.txt"):
        m = line.strip().split("|")
        person = m[0].strip()
        movie = m[1].strip()
        
        ##Note: person in movies.keys() is O(n) and hence too costly
        ##So, we keep the list of all actors in a set and use that instead
        ##to speed things up
        if person in actors:  
            movies[person].add(movie)
        else:
            movies[person] = set([movie])
            actors.add( person )

    ##Find actors with the highest number of movies
    movie_counts = []
    for key in movies.keys():
        movie_counts.append( [len(movies[key]), key] )
    movie_counts.sort(reverse=True)
    
    for i in range(10):
        print "%i. %s (%d movies)" %(i+1, movie_counts[i][1], movie_counts[i][0])
        

