"""This program illustrates the use of dictionaries to process the
movies for each actor. 

Read movie data into a dictionary called movies:
   key: name of an actor
   value: set of all the movies for that actor


Algorithm to find the movies two actors have in common, 
and print this if two actors have at least 5 movies in common

As the data is large, we will only read actors with name starting with
O for this part. Note the algorithm for this part is n^3, so it will
take a long time.

for person1 in people:
    for person2 in people:
        if person1 != person2:
            find movies they have in common
            if more than five, add to a list

"""

if __name__ == '__main__':
    movies = {}
    actors = set()
    for line in open("imdb_data.txt"):
        m = line.strip().split("|")
        person = m[0].strip()
        movie = m[1].strip()
        
        if person.startswith('O'):
            ##Note: person in movies.keys() is O(n) and hence too costly
            ##So, we keep the list of all actors in a set and use that instead
            ##to speed things up
            if person in actors:  
                movies[person].add( movie )
            else:
                movies[person] = set( [movie] )
                actors.add( person )

    # This code finds the movies in common for all pairs of actors
    # It is an n^3 algorithm, hence too slow
    print "Now processing movies in common"            
    actors = list(actors)
    for p1 in range(len(actors)-1):
        for p2 in range(p1+1,len(actors)): 
            person1 = actors[p1]
            person2 = actors[p2]
            in_common = movies[person1] & movies[person2]
            if len(in_common) > 2:
                print "%s/%s" %(person1, person2)
                print "Movies:"
                for item in in_common:
                    print "\t%s" %item
                print
                
        

