"""List based solution to find the number of movies for each person

   We will use a list of lists of the form:

   movies = [ [Actorname, number_of_movies], ... ]   
   
   movies = []
   for line in file:
       read person name
       find index i for person in movies list
       if person is not in the list:
           movies.append ( [person, 1] )
       else:
            movies[i][1] += 1


Complexity:
   find if person in the list, O(m) where m is the number of items in the list
   this is repeated for all the lines in the data, O(n)

   Assume n and m are roughly the same, total complexity is O(n**2)

   Because of its high complexity, so we will use a smaller file
   instead.  Compare this with the dictionary solution
   ("hanks_dictionary.py") which is cheaper (about O(n) in the
   average).

"""


def person_in_list(movies, person):
    for i in range(len(movies)):
        if movies[i][0] == person:
            return i
    return None

if __name__ == '__main__':
    movies = []
    for line in open("hanks.txt"):
        m = line.strip().split("|")
        person = m[0].strip()
        i = person_in_list(movies, person)
        if i == None:
            movies.append( [person, 1])
        else:
            movies[i][1] += 1
        
    for item in movies:
        print item
